@@ -8,9 +8,9 @@
 #include "akregator_config_archive.h"
 #include "ui_settings_archive.h"
 #include <KAboutData>
+#include <KLocalization>
 #include <KLocalizedString>
 #include <KPluginFactory>
-
 #include <QButtonGroup>
 #include <QVBoxLayout>
 
@@ -30,8 +30,8 @@ KCMAkregatorArchiveConfig::KCMAkregatorArchiveConfig(QObject *parent, const KPlu
     connect(m_ui.rb_LimitArticleNumber, &QAbstractButton::toggled, m_ui.kcfg_MaxArticleNumber, &QWidget::setEnabled);
     connect(m_ui.rb_LimitArticleAge, &QAbstractButton::toggled, m_ui.kcfg_MaxArticleAge, &QWidget::setEnabled);
 
-    m_ui.kcfg_MaxArticleNumber->setSuffix(ki18ncp("Limit feed archive size to:", " article", " articles"));
-    m_ui.kcfg_MaxArticleAge->setSuffix(ki18ncp("Delete articles older than:", " day", " days"));
+    KLocalization::setupSpinBoxFormatString(m_ui.kcfg_MaxArticleNumber, ki18ncp("Limit feed archive size to:", "%v article", "%v articles"));
+    KLocalization::setupSpinBoxFormatString(m_ui.kcfg_MaxArticleAge, ki18ncp("Delete articles older than:", "%v day", "%v days"));
     m_archiveModeGroup = new QButtonGroup(this);
     m_archiveModeGroup->addButton(m_ui.rb_KeepAllArticles, Settings::EnumArchiveMode::keepAllArticles);
     m_archiveModeGroup->addButton(m_ui.rb_LimitArticleNumber, Settings::EnumArchiveMode::limitArticleNumber);
