@@ -7,7 +7,6 @@
 
 #pragma once
 
-#include "kcmutils_version.h"
 #include <KCModule>
 #include <QVariant>
 
@@ -20,11 +19,7 @@ class KCMAkregatorArchiveConfig : public KCModule
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMAkregatorArchiveConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMAkregatorArchiveConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMAkregatorArchiveConfig(QObject *parent, const KPluginMetaData &data);
 
     void setArchiveMode(int mode);
     int archiveMode() const;
