@@ -25,6 +25,6 @@ public:
     void defaults() override;
 
 private:
-    KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
+    KUserFeedback::FeedbackConfigWidget *const mUserFeedbackWidget;
 };
 }
