@@ -20,7 +20,11 @@ protected:
     bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 
 private:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    void slotFeaturePermissionRequested(QWebEnginePermission feature);
+#else
     void slotFeaturePermissionRequested(const QUrl &url, QWebEnginePage::Feature feature);
+#endif
     void onLoadProgress();
 };
 }
