@@ -8,14 +8,19 @@
 
 #include "article.h"
 #include "articleformatter.h"
-#include <GrantleeTheme/GenericFormatter>
+#include <GrantleeTheme/GrantleeThemeEngine>
+
 namespace Akregator
 {
+struct Colors {
+    QString colorScheme;
+    QString backgroundColor;
+};
 class Folder;
-class GrantleeViewFormatter : public GrantleeTheme::GenericFormatter
+class GrantleeViewFormatter
 {
 public:
-    explicit GrantleeViewFormatter(const QString &htmlFileName, const QString &themePath, int deviceDpiY);
+    explicit GrantleeViewFormatter(const QString &htmlFileName, int deviceDpiY);
     ~GrantleeViewFormatter();
 
     [[nodiscard]] QString formatArticles(const QList<Article> &article, ArticleFormatter::IconOption icon);
@@ -23,12 +28,14 @@ public:
     [[nodiscard]] QString formatFeed(Akregator::Feed *feed);
 
 private:
+    Colors getAppColor() const;
     void addStandardObject(QVariantHash &grantleeObject) const;
-    [[nodiscard]] QString sidebarCss() const;
+    [[nodiscard]] QString sidebarCss(const Colors &colors) const;
     [[nodiscard]] int pointsToPixel(int pointSize) const;
     const QString mHtmlArticleFileName;
     const QString mDirectionString;
-    const QString mGrantleeThemePath;
+    GrantleeTheme::Engine mEngine;
+    KTextTemplate::Template mTemplate;
     const int mDeviceDpiY;
 };
 }
