@@ -14,6 +14,9 @@
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #endif
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/activitiesmanager.h"
+#endif
 
 using namespace Akregator;
 
@@ -29,10 +32,12 @@ Kernel *Kernel::self()
 }
 
 Kernel::Kernel()
+    : m_fetchQueue(new FetchQueue())
+    , m_frameManager(new FrameManager())
+#if HAVE_ACTIVITY_SUPPORT
+    , mActivitiesManager(new ActivitiesManager())
+#endif
 {
-    m_fetchQueue = new FetchQueue();
-    m_frameManager = new FrameManager();
-    m_storage = nullptr;
 #ifdef WITH_KUSERFEEDBACK
     // Initialize
     (void)UserFeedBackManager::self();
@@ -43,8 +48,18 @@ Kernel::~Kernel()
 {
     delete m_fetchQueue;
     delete m_frameManager;
+#if HAVE_ACTIVITY_SUPPORT
+    delete mActivitiesManager;
+#endif
 }
 
+#if HAVE_ACTIVITY_SUPPORT
+ActivitiesManager *Kernel::activitiesManager() const
+{
+    return mActivitiesManager;
+}
+#endif
+
 Backend::Storage *Kernel::storage()
 {
     return m_storage;
