@@ -27,13 +27,9 @@ ProgressManager *ProgressManager::self()
     return m_self;
 }
 
-ProgressManager::ProgressManager()
-{
-}
+ProgressManager::ProgressManager() = default;
 
-ProgressManager::~ProgressManager()
-{
-}
+ProgressManager::~ProgressManager() = default;
 
 void ProgressManager::setFeedList(const QSharedPointer<FeedList> &feedList)
 {
@@ -50,7 +46,7 @@ void ProgressManager::setFeedList(const QSharedPointer<FeedList> &feedList)
     m_feedList = feedList;
 
     if (m_feedList) {
-        const QVector<Feed *> list = feedList->feeds();
+        const QList<Feed *> list = feedList->feeds();
 
         for (TreeNode *i : list) {
             slotNodeAdded(i);
@@ -151,3 +147,5 @@ void ProgressItemHandler::slotFetchAborted()
         m_progressItem = nullptr;
     }
 }
+
+#include "moc_progressmanager.cpp"
