@@ -7,9 +7,12 @@
 */
 
 #include "subscriptionlistmodel.h"
+#include "akregatorconfig.h"
+#include "config-akregator.h"
 #include "feed.h"
 #include "feedlist.h"
 #include "folder.h"
+#include "kernel.h"
 #include "subscriptionlistjobs.h"
 #include "treenode.h"
 
@@ -29,7 +32,9 @@
 #include <QStyle>
 #include <QUrl>
 #include <QVariant>
-
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/activitiesmanager.h"
+#endif
 using namespace Akregator;
 using namespace Syndication;
 
@@ -70,42 +75,56 @@ static const TreeNode *nodeForIndex(const QModelIndex &index, const FeedList *fe
 }
 }
 // TODO add activities support here.
-FilterUnreadProxyModel::FilterUnreadProxyModel(QObject *parent)
+FilterSubscriptionProxyModel::FilterSubscriptionProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
     , m_selectedHierarchy()
 {
 }
 
-bool FilterUnreadProxyModel::doFilter() const
+bool FilterSubscriptionProxyModel::doFilter() const
 {
     return m_doFilter;
 }
 
-void FilterUnreadProxyModel::setDoFilter(bool v)
+void FilterSubscriptionProxyModel::activitiesChanged()
+{
+    invalidateFilter();
+}
+
+void FilterSubscriptionProxyModel::setDoFilter(bool v)
 {
     m_doFilter = v;
     invalidateFilter();
 }
 
-void FilterUnreadProxyModel::setSourceModel(QAbstractItemModel *src)
+void FilterSubscriptionProxyModel::setSourceModel(QAbstractItemModel *src)
 {
     clearCache();
     QSortFilterProxyModel::setSourceModel(src);
 }
 
-bool FilterUnreadProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
+bool FilterSubscriptionProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
+    const QModelIndex idx = sourceModel()->index(source_row, 0, source_parent);
+#if HAVE_ACTIVITY_SUPPORT
+    if (Kernel::self()->activitiesManager()->enabled()) {
+        if (idx.data(SubscriptionListModel::ActivityEnabled).toBool()) {
+            if (!Kernel::self()->activitiesManager()->isInCurrentActivity(idx.data(SubscriptionListModel::Activities).toStringList())) {
+                return false;
+            }
+        }
+    }
+#endif
+
     if (!m_doFilter) {
         return true;
     }
 
-    const QModelIndex idx = sourceModel()->index(source_row, 0, source_parent);
-
     if (m_selectedHierarchy.contains(idx)) {
         return true;
     }
 
-    QVariant v = idx.data(SubscriptionListModel::HasUnreadRole);
+    const QVariant v = idx.data(SubscriptionListModel::HasUnreadRole);
     if (v.isNull()) {
         return true;
     }
@@ -119,7 +138,7 @@ bool FilterUnreadProxyModel::filterAcceptsRow(int source_row, const QModelIndex
  * which would occur otherwise (we'd select the last article to read, it would
  * become unread, and disappear from the list without letting us view it).
  **/
-void FilterUnreadProxyModel::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+void FilterSubscriptionProxyModel::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     QModelIndexList desel = mapSelectionToSource(deselected).indexes();
     // calling invalidateFilter causes refiltering at the call point, so we should
@@ -135,10 +154,10 @@ void FilterUnreadProxyModel::selectionChanged(const QItemSelection &selected, co
 
     clearCache();
 
-    QModelIndexList sel = mapSelectionToSource(selected).indexes();
+    const QModelIndexList sel = mapSelectionToSource(selected).indexes();
     if (!sel.isEmpty()) {
         // XXX add support for multiple selections? this doesn't generally make sense in this case honestly
-        QModelIndex current = sel.at(0);
+        QModelIndex current = sel.constFirst();
         while (current.isValid()) {
             m_selectedHierarchy.insert(current);
             current = current.parent();
@@ -150,7 +169,7 @@ void FilterUnreadProxyModel::selectionChanged(const QItemSelection &selected, co
     }
 }
 
-void FilterUnreadProxyModel::clearCache()
+void FilterSubscriptionProxyModel::clearCache()
 {
     m_selectedHierarchy.clear();
 }
@@ -256,6 +275,10 @@ QVariant SubscriptionListModel::data(const QModelIndex &index, int role) const
     }
     case HasUnreadRole:
         return node->unread() > 0;
+    case Activities:
+        return feed ? feed->activities() : QVariant();
+    case ActivityEnabled:
+        return feed ? feed->activityEnabled() : QVariant();
     }
 
     return {};
@@ -448,9 +471,7 @@ Qt::ItemFlags SubscriptionListModel::flags(const QModelIndex &idx) const
 
 QStringList SubscriptionListModel::mimeTypes() const
 {
-    QStringList types;
-    types << QStringLiteral("text/uri-list") << AKREGATOR_TREENODE_MIMETYPE;
-    return types;
+    return {QStringLiteral("text/uri-list"), AKREGATOR_TREENODE_MIMETYPE};
 }
 
 QMimeData *SubscriptionListModel::mimeData(const QModelIndexList &indexes) const
