@@ -26,11 +26,11 @@ class TreeNode;
 /**
  * Filters feeds with unread counts.
  */
-class FilterUnreadProxyModel : public QSortFilterProxyModel
+class FilterSubscriptionProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    explicit FilterUnreadProxyModel(QObject *parent = nullptr);
+    explicit FilterSubscriptionProxyModel(QObject *parent = nullptr);
 
     [[nodiscard]] bool doFilter() const;
 
@@ -38,6 +38,7 @@ public:
 
     void setSourceModel(QAbstractItemModel *src) override;
 
+    void activitiesChanged();
 public Q_SLOTS:
     void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
     void clearCache();
@@ -64,6 +65,8 @@ public:
         IdRole,
         IsOpenRole,
         HasUnreadRole,
+        Activities,
+        ActivityEnabled,
     };
 
     enum Column {
