@@ -7,7 +7,7 @@
 #include "urlhandlerwebenginemanager.h"
 #include "urlhandlerwebengine.h"
 
-#include <articleviewer-ng/webengine/articleviewerwebengine.h>
+#include "articleviewer-ng/webengine/articleviewerwebengine.h"
 
 using std::remove;
 
