@@ -25,6 +25,6 @@ void StatusSearchButtonsTest::shouldHaveDefaultValues()
 
     auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), QMargins{});
-    QCOMPARE(mainLayout->spacing(), 0);
 }
+
+#include "moc_statussearchbuttonstest.cpp"
